/****************************************************************************

 This file is part of the QGLViewer library
 Copyright (C) 2002, 2003, 2004  Gilles Debunne (Gilles.Debunne@imag.fr)
 Version 1.3.9-2, released on December 3, 2004.

 http://artis.imag.fr/Members/Gilles.Debunne/QGLViewer

 libQGLViewer is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 libQGLViewer is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with libQGLViewer; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*****************************************************************************/

///////////////////////////////////////////////////////////////////
//               libQGLViewer configuration file                 //
//  Modify these settings according to your local configuration  //
///////////////////////////////////////////////////////////////////

#ifndef QGLVIEWER_CONFIG_H
#define QGLVIEWER_CONFIG_H

#define QGLVIEWER_VERSION 0x010309

#ifndef QT_CLEAN_NAMESPACE
# define QT_CLEAN_NAMESPACE
#endif

// Get QT_VERSION and other Qt flags
#include <qglobal.h>

#if QT_VERSION < 300
# ifdef _OS_WIN32_
# define Q_OS_WIN32
# endif
#endif

// Win 32 DLL export macros
#ifdef Q_OS_WIN32
# include <windows.h> // Warning : windows.h must be included BEFORE gl.h
# ifndef M_PI
#  define M_PI 3.14159265358979323846f
# endif
# ifdef MAKE_QGLVIEWER_DLL
#  define QGLVIEWER_EXPORT  __declspec(dllexport)
# else
#  define QGLVIEWER_EXPORT  __declspec(dllimport)
# endif
# pragma warning( disable : 4251 ) // DLL interface
#endif // Q_OS_WIN32

// For other architectures, this macro is empty
#ifndef QGLVIEWER_EXPORT
# define QGLVIEWER_EXPORT
#endif

// OpenGL includes (see windows.h warning above)
// Included here and hence shared by all files that need OpenGL headers.
#include <qgl.h>

// Old Qt versions require GLUT for text rendering
#define QT_VERSION_WITHOUT_GLUT 0x030100
#if QT_VERSION < QT_VERSION_WITHOUT_GLUT
# ifdef Q_OS_MAC
#  include <GLUT/glut.h>
# else
#  ifdef Q_OS_WIN32
#   include <glut.h>
#  else
#   include <GL/glut.h>
#  endif
# endif
#endif

// Qt 2.3 compatibility patches
#if QT_VERSION < 300
# pragma warning( disable : 4530 ) // exception handler but unwind semantics. Same as GX option
# include <vector> // also defines std::max and std::abs
# define QValueVector std::vector
# include <qlist.h>
# define QPtrList QList
# define QPtrListIterator QListIterator
# ifndef DOXYGEN
  // Used only to detect a Reality Center configuration for stereo mode.
  class QDesktopWidget
  {
  public:
    int width()  const { return 1280; };
    int height() const { return 1024; };
  };
# endif
#else
# include <qptrlist.h>
# include <qvaluevector.h>
#endif

// Patch for gcc version <= 2.95. Seems to no longer be needed with recent Qt versions.
// Uncomment these lines if you have error message dealing with operator << on QStrings

// #if defined(__GNUC__) && defined(__GNUC_MINOR__) && (__GNUC__ < 3) && (__GNUC_MINOR__ < 96)
// # include <iostream>
// # include <qstring.h>
// std::ostream& operator<<(std::ostream& out, const QString& str)
// { out << str.latin1();  return out; }
// #endif

#endif // QGLVIEWER_CONFIG_H
